@@ -3,7 +3,7 @@
 # ${2} - bump: <major|minor>
 # ${3} - twine: <"${GITHUB_USERNAME}"|"${NFERX_GITHUB_USERNAME}"|pypi>
 # shellcheck disable=SC2034
-export source="${BASH_SOURCE[0]}"; debug.sh source
+export starting="${BASH_SOURCE[0]}"; debug.sh starting
 
 if ! isuser.sh; then
   error.sh "can not be done with root"; exit 1
@@ -72,4 +72,4 @@ fi
 
 cd - > /dev/null || exit 1
 
-unset source bump twine virtual file error name path
+unset starting bump twine virtual file error name path
